@@ -76,7 +76,6 @@ Controller::Controller(QObject *parent)
 Controller::~Controller()
 {
     for (auto c : qAsConst(m_connections)) {
-        c->stopSync();
         c->saveState();
     }
 }
@@ -110,7 +109,7 @@ void Controller::loginWithCredentials(const QString &serverAddr, const QString &
     // we are using a fake mixd since resolveServer just set the homeserver url :sigh:
     conn->resolveServer("@username:" + serverUrl.host() + ":" + QString::number(serverUrl.port(443)));
 
-    connect(conn, &Connection::homeserverChanged, this, [this, user, conn, pass, deviceName]() {
+    connect(conn, &Connection::loginFlowsChanged, this, [this, user, conn, pass, deviceName]() {
         conn->loginWithPassword(user, pass, deviceName, "");
         connect(conn, &Connection::connected, this, [this, conn, deviceName] {
             AccountSettings account(conn->userId());
@@ -198,7 +197,7 @@ void Controller::logout(Connection *conn, bool serverSideLogout)
     conn->stopSync();
     Q_EMIT conn->stateChanged();
     Q_EMIT conn->loggedOut();
-    if (!m_connections.isEmpty()) {
+    if (conn == activeConnection() && !m_connections.isEmpty()) {
         setActiveConnection(m_connections[0]);
     } else {
         setActiveConnection(nullptr);
@@ -232,11 +231,18 @@ void Controller::addConnection(Connection *c)
         dropConnection(c);
     });
 
+    connect(c, &Connection::requestFailed, this, [=] (BaseJob *job) {
+        if(job->error() == BaseJob::UserConsentRequiredError) {
+            Q_EMIT userConsentRequired(job->errorUrl());
+        }
+    });
+
     setBusy(true);
 
     c->sync();
 
     Q_EMIT connectionAdded(c);
+    Q_EMIT accountCountChanged();
 }
 
 void Controller::dropConnection(Connection *c)
@@ -245,50 +251,50 @@ void Controller::dropConnection(Connection *c)
     m_connections.removeOne(c);
 
     Q_EMIT connectionDropped(c);
+    Q_EMIT accountCountChanged();
     c->deleteLater();
 }
 
 void Controller::invokeLogin()
 {
     const auto accounts = SettingsGroup("Accounts").childGroups();
+    QString id = NeoChatConfig::self()->activeConnection();
     for (const auto &accountId : accounts) {
         AccountSettings account {accountId};
+        if (id.isEmpty()) {
+            // handle case where the account config is empty
+            id = accountId;
+        }
         if (!account.homeserver().isEmpty()) {
             auto accessToken = loadAccessTokenFromKeyChain(account);
 
-            auto c = new Connection(account.homeserver(), this);
-            connect(c, &Connection::connected, this, [=] {
-                c->loadState();
-                addConnection(c);
-            });
-            connect(c, &Connection::loginError, this, [=](const QString &error, const QString &) {
-                if (error == "Unrecognised access token") {
-                    Q_EMIT errorOccured(i18n("Login Failed"), i18n("Access Token invalid or revoked"));
-                    logout(c, false);
-                } else {
-                    Q_EMIT errorOccured(i18n("Login Failed"), error);
-                    logout(c, true);
+            auto connection = new Connection(account.homeserver(), this);
+            connect(connection, &Connection::connected, this, [=] {
+                connection->loadState();
+                addConnection(connection);
+                if (connection->userId() == id) {
+                    setActiveConnection(connection);
+                    Q_EMIT initiated();
                 }
             });
-            connect(c, &Connection::networkError, this, [=](const QString &error, const QString &, int, int) {
+            connect(connection, &Connection::loginError, this, [=](const QString &error, const QString &) {
+                if (error == "Unrecognised access token") {
+                    Q_EMIT errorOccured(i18n("Login Failed"), i18n("Access Token invalid or revoked"));
+                    logout(connection, false);
+                } else {
+                    Q_EMIT errorOccured(i18n("Login Failed"), error);
+                    logout(connection, true);
+                }
+            });
+            connect(connection, &Connection::networkError, this, [=](const QString &error, const QString &, int, int) {
                 Q_EMIT errorOccured("Network Error", error);
             });
-            c->connectWithToken(account.userId(), accessToken, account.deviceId());
+            connection->connectWithToken(account.userId(), accessToken, account.deviceId());
         }
     }
-
-    if (!m_connections.isEmpty()) {
-        const QString id = NeoChatConfig::self()->activeConnection();
-        for (auto *connection : qAsConst(m_connections)) {
-            if (connection->userId() == id) {
-                setActiveConnection(connection);
-                Q_EMIT initiated();
-                return;
-            }
-        }
-        setActiveConnection(m_connections[0]);
+    if (m_connections.isEmpty()) {
+        Q_EMIT initiated();
     }
-    Q_EMIT initiated();
 }
 
 QByteArray Controller::loadAccessTokenFromFile(const AccountSettings &account)
