@@ -44,6 +44,7 @@ QHash<int, QByteArray> MessageEventModel::roleNames() const
     roles[ShowAuthorRole] = "showAuthor";
     roles[ShowSectionRole] = "showSection";
     roles[ReactionRole] = "reaction";
+    roles[IsEditedRole] = "isEdited";
     return roles;
 }
 
@@ -301,6 +302,7 @@ inline QVariantMap userAtEvent(NeoChatUser *user, NeoChatRoom *room, const RoomE
         {"avatarMediaId", user->avatarMediaId(room)},
         {"avatarUrl", user->avatarUrl(room)},
         {"displayName", user->displayname(room)},
+        {"display", user->name()},
         {"color", user->color()},
         {"object", QVariant::fromValue(user)},
     };
@@ -415,6 +417,11 @@ QVariant MessageEventModel::data(const QModelIndex &idx, int role) const
             }
         }
 
+        // isReplacement?
+        if (auto e = eventCast<const RoomMessageEvent>(&evt))
+            if (!e->replacedEvent().isEmpty())
+                return EventStatus::Hidden;
+
         if (is<RedactionEvent>(evt) || is<ReactionEvent>(evt)) {
             return EventStatus::Hidden;
         }
@@ -439,6 +446,13 @@ QVariant MessageEventModel::data(const QModelIndex &idx, int role) const
         return EventStatus::Normal;
     }
 
+    if (role == IsEditedRole) {
+        if (auto e = eventCast<const RoomMessageEvent>(&evt)) {
+            return !e->unsignedJson().isEmpty() && e->unsignedJson().contains("m.relations") && e->unsignedJson()["m.relations"].toObject().contains("m.replace");
+        }
+        return false;
+    }
+
     if (role == EventIdRole) {
         return !evt.id().isEmpty() ? evt.id() : evt.transactionId();
     }
